@@ -12,12 +12,18 @@ use Carp;
 use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
 use File::chdir;
+use Getopt::Alt;
 
-our $VERSION     = version->new('0.1.5');
+our $VERSION     = version->new('0.2.0');
 
 requires 'repos';
 requires 'verbose';
 
+my $opt = Getopt::Alt->new(
+    { help => __PACKAGE__, },
+    [ 'quote|q!', ]
+);
+
 sub status {
     my ($self, $name) = @_;
     return unless -d $name;
@@ -46,7 +52,7 @@ Group::Git::Cmd::Status - Runs git status on a git project
 
 =head1 VERSION
 
-This documentation refers to Group::Git::Cmd::Status version 0.1.5.
+This documentation refers to Group::Git::Cmd::Status version 0.2.0.
 
 
 =head1 SYNOPSIS
@@ -64,7 +70,7 @@ This documentation refers to Group::Git::Cmd::Status version 0.1.5.
 
 =over 4
 
-=item C<status ()>
+=item C<status ($name)>
 
 Runs git status on each directory if the status message includes:
 
